# **What is Lynxy?**
<b>Lively <br>
(Yielding?) <br>
Network <br>
(eXchange?) <br>
(the extra y is cosmetic~)</b>

***

Lynxy is a client system coded in Python for ease of communication. It allows for easy set up for connecting
machines to each other, as well as providing a lot of extra features. 

The goal of Lynxy is to make it easier for others to set up multiplayer applications, no matter what they intend to make. From texting applications to games to streaming services, the possiblities are endless! Read more to learn the ways you can use Lynxy.

***

Information about functions can be found [here](/docs/github/functions.md)!

Information about data types for events can be found [here](/docs/github/events.md)!

Changelog can be found [here](/docs/github/changelogs/release_changelog.md)!

Experimental changelog can be found [here](/docs/github/changelogs/experimental_changelog.md)!

Version info can be found [here](/docs/github/version%20key.md)!